==> jc-1.4.0.tar.gz: java/lang/UnknownError.h <==
// public class java.lang.UnknownError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 5078979d61848ebb java_lang_UnknownError
// @dep_class c7632ae877826bc6 java_lang_VirtualMachineError

// header file dependencies
// @dep_header java_lang_VirtualMachineError

#include "java/lang/VirtualMachineError.h"

#ifndef _JC_java_lang_UnknownError_H_
#define _JC_java_lang_UnknownError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_UnknownError$sub_refs	_jc_java_lang_UnknownError$sub_refs;
typedef struct _jc_java_lang_UnknownError$sub_nonrefs	_jc_java_lang_UnknownError$sub_nonrefs;
typedef struct _jc_java_lang_UnknownError$refs	_jc_java_lang_UnknownError$refs;
typedef struct _jc_java_lang_UnknownError$nonrefs	_jc_java_lang_UnknownError$nonrefs;
typedef struct _jc_java_lang_UnknownError$object	_jc_java_lang_UnknownError$object;

typedef struct _jc_java_lang_UnknownError$fields_struct	_jc_java_lang_UnknownError$fields_struct;
typedef const struct _jc_java_lang_UnknownError$vmethods	_jc_java_lang_UnknownError$vmethods;
typedef const struct _jc_java_lang_UnknownError$vtable	_jc_java_lang_UnknownError$vtable;
typedef const struct _jc_java_lang_UnknownError$vtype	_jc_java_lang_UnknownError$vtype;

// Class fields structure
struct _jc_java_lang_UnknownError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_UnknownError$fields_struct _jc_java_lang_UnknownError$class_fields;

// Constructors
extern void _jc_java_lang_UnknownError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_UnknownError$object *);
extern void _jc_java_lang_UnknownError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_UnknownError$object *, struct _jc_java_lang_String$object *);

// Virtual methods structure
struct _jc_java_lang_UnknownError$vmethods {
};

// Vtable
struct _jc_java_lang_UnknownError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_VirtualMachineError$vmethods	java_lang_VirtualMachineError;
	_jc_java_lang_UnknownError$vmethods	java_lang_UnknownError;
};

// Vtype
struct _jc_java_lang_UnknownError$vtype {
	_jc_type			type;
	_jc_java_lang_UnknownError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_UnknownError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_UnknownError$refs {
    _jc_java_lang_UnknownError$sub_refs	java_lang_UnknownError;
    _jc_java_lang_VirtualMachineError$sub_refs	java_lang_VirtualMachineError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_UnknownError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_UnknownError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_VirtualMachineError$sub_nonrefs	java_lang_VirtualMachineError;
    _jc_java_lang_UnknownError$sub_nonrefs	java_lang_UnknownError;
};

// Object instance structure
struct _jc_java_lang_UnknownError$object {
	_jc_java_lang_UnknownError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_UnknownError$vtype	*vtype;
	_jc_java_lang_UnknownError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_UnknownError$vtype _jc_java_lang_UnknownError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_UnknownError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_UnknownError$class_object;

#endif	/* _JC_java_lang_UnknownError_H_ */

==> jc-1.4.6.tar.gz: java/lang/UnknownError.h <==
// public class java.lang.UnknownError

// class file dependencies
// @dep_class 308333d803f5ab9f java_lang_Error
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 5078979d61848ebb java_lang_UnknownError
// @dep_class c7632ae877826bc6 java_lang_VirtualMachineError

// header file dependencies
// @dep_header java_lang_VirtualMachineError

#include "java/lang/VirtualMachineError.h"

#ifndef _JC_java_lang_UnknownError_H_
#define _JC_java_lang_UnknownError_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_lang_UnknownError$sub_refs	_jc_java_lang_UnknownError$sub_refs;
typedef struct _jc_java_lang_UnknownError$sub_nonrefs	_jc_java_lang_UnknownError$sub_nonrefs;
typedef struct _jc_java_lang_UnknownError$refs	_jc_java_lang_UnknownError$refs;
typedef struct _jc_java_lang_UnknownError$nonrefs	_jc_java_lang_UnknownError$nonrefs;
typedef struct _jc_java_lang_UnknownError$object	_jc_java_lang_UnknownError$object;

typedef struct _jc_java_lang_UnknownError$fields_struct	_jc_java_lang_UnknownError$fields_struct;
typedef const struct _jc_java_lang_UnknownError$vmethods	_jc_java_lang_UnknownError$vmethods;
typedef const struct _jc_java_lang_UnknownError$vtable	_jc_java_lang_UnknownError$vtable;
typedef const struct _jc_java_lang_UnknownError$vtype	_jc_java_lang_UnknownError$vtype;

// Class fields structure
struct _jc_java_lang_UnknownError$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_lang_UnknownError$fields_struct _jc_java_lang_UnknownError$class_fields;

// Constructors
extern void _jc_java_lang_UnknownError$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_lang_UnknownError$object *) _JC_JCNI_ATTR;
extern void _jc_java_lang_UnknownError$method$_init$c31b894660454d13(_jc_env *, struct _jc_java_lang_UnknownError$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_lang_UnknownError$vmethods {
};

// Vtable
struct _jc_java_lang_UnknownError$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Error$vmethods	java_lang_Error;
	_jc_java_lang_VirtualMachineError$vmethods	java_lang_VirtualMachineError;
	_jc_java_lang_UnknownError$vmethods	java_lang_UnknownError;
};

// Vtype
struct _jc_java_lang_UnknownError$vtype {
	_jc_type			type;
	_jc_java_lang_UnknownError$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_lang_UnknownError$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_lang_UnknownError$refs {
    _jc_java_lang_UnknownError$sub_refs	java_lang_UnknownError;
    _jc_java_lang_VirtualMachineError$sub_refs	java_lang_VirtualMachineError;
    _jc_java_lang_Error$sub_refs	java_lang_Error;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_lang_UnknownError$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_lang_UnknownError$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Error$sub_nonrefs	java_lang_Error;
    _jc_java_lang_VirtualMachineError$sub_nonrefs	java_lang_VirtualMachineError;
    _jc_java_lang_UnknownError$sub_nonrefs	java_lang_UnknownError;
};

// Object instance structure
struct _jc_java_lang_UnknownError$object {
	_jc_java_lang_UnknownError$refs	refs[0];
	_jc_word		lockword;
	_jc_java_lang_UnknownError$vtype	*vtype;
	_jc_java_lang_UnknownError$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_lang_UnknownError$vtype _jc_java_lang_UnknownError$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_lang_UnknownError, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_lang_UnknownError$class_object;

#endif	/* _JC_java_lang_UnknownError_H_ */
